      SUBROUTINE ISSURF(isurf,m,latindex,lonindex,itimeindex)

C  ISSURF CHECKS IF THIS PROBE IS A SURFACE-ONLY PROBE
C  THE PRESENT WAY TO DO THIS IS TO SEE IF THE PROBE
C  MEASURES LATITUDE, LONGITUDE, AND JULIAN DAY 

c*********************************************************
c
c   Passed Variables:
c
c    isurf - 0= not surface-only
c            1= surface only
c    m - probe code
c    latindex - latitude parameter code
c    lonindex - longitude parameter code
c    itimeindex - julian day parameter code
c
c**********************************************************

      parameter (maxcalc=200, maxprobe=100)
      common /parmord/ nprec(maxcalc,maxprobe)

      latindex=0
      lonindex=0 
      itimeindex=0

      call getforsurf(1,latindex)
      call getforsurf(2,lonindex)
      call getforsurf(3,itimeindex)
c     if ( latindex .eq. 0 ) call getforsurf(1,latindex)
c     if ( lonindex .eq. 0 ) call getforsurf(2,lonindex)
c     if ( itimeindex .eq. 0 ) call getforsurf(3,itimeindex)

      isurf=0
      isurfx=0

      call getsurfprobe(m,isurfx)
      if ( latindex .gt. 0 .and. lonindex .gt. 0 .and.
     *     itimeindex .gt. 0 .and. nprec(latindex,m) .gt. 0 .and.
     *     nprec(lonindex,m) .gt. 0 .and.
     *     nprec(itimeindex,m) .gt. 0 .and. isurfx .eq. 1) isurf=1

      return
      end
